@@ -50,7 +50,7 @@ int handle_internal_pd(struct menuinfo *mi, int action, int reqtype)
   smapi_outparm_t *result;
   static int tmp;
   int chconfig=FALSE;
-  char *tmp_str;
+  char *tmp_str = NULL;
 
   if((result=do_smapi(0x11,0x02,reqtype << 8,0,0,0,0,FALSE))==NULL) return 1;
  
@@ -117,7 +117,7 @@ int handle_internal_pd(struct menuinfo *mi, int action, int reqtype)
 int handle_external_pd(struct menuinfo *mi, int action, int reqtype)
 {
   smapi_outparm_t *result;
-  int tmp;
+  int tmp = 0;
   int chconfig=FALSE;
 
   if((result=do_smapi(0x11,0x02,reqtype << 8,0,0,0,0,FALSE))==NULL) return 1;
